<?php
if(PHP_VERSION >= 5) {
	// Emulate the old xslt library functions
	function xslt_create() {
		return new XsltProcessor();
	}

	function xslt_process($xsltproc, 
	                      $xml_arg, 
	                      $xsl_arg, 
	                      $xslcontainer = null, 
	                      $args = null, 
	                      $params = null) {

		// Start with preparing the arguments
		$xml_arg = str_replace('arg:', '', $xml_arg);
		$xsl_arg = str_replace('arg:', '', $xsl_arg);

		// Load the xml document and the xsl template
		// creating instances of the DomDocument class
		$xml = DOMDocument::loadXML($args[$xml_arg]);
		$xsl = DOMDocument::loadXML($args[$xsl_arg]);

		// Load the xsl template
		$xsltproc->importStyleSheet($xsl);

		// Set parameters when defined
		if($params) {
			foreach($params as $param => $value) {
				$xsltproc->setParameter("", $param, $value);
			}
		}

		// Start the transformation
		$processed = $xsltproc->transformToXML($xml);

		// Put the result in a file when specified
		if($xslcontainer) {
			return @file_put_contents($xslcontainer, $processed);
		} else {
			return $processed;
		}
	}

	function xslt_free($xsltproc) {
		unset($xsltproc);
	}
}

if(!function_exists('file_get_contents')) {
	function file_get_contents($file) {
		$v = file($file);
		return ($v) ? implode('', $v) : false;
	}
}

if(!function_exists('file_put_contents')) {
	function file_put_contents($filename, $data, $file_append = false) {
		$fp = fopen($filename, (!$file_append ? 'w+' : 'a+'));
		if(!$fp) {
			trigger_error('file_put_contents cannot write in file.', E_USER_ERROR);
		} else {
			fputs($fp, $data);
			fclose($fp);
		}
	}
}

################################################################################
$arguments = array(
  '/_xml' => file_get_contents('headlines.rss'),
  '/_xsl' => file_get_contents('rss2pm.xsl')
);
$params = array(
	'count' => 3
);

$xh = xslt_create();
$result = xslt_process($xh, 'arg:/_xml', 'arg:/_xsl', NULL, $arguments, $params);
xslt_free($xh);

echo '<code><pre>';
echo htmlentities($arguments['/_xml']);
echo '</pre></code>';
echo "<hr/>";
echo '<code><pre>';
echo htmlentities($result);
echo '</pre></code>';
